==> qtjambi-xml-debuginfo-windows-x64-6.5.8.jar: sources/QtJambiXml/QDomDocument_ParseResult_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiXml/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomDocument_ParseResult(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomDocument::ParseResult")
    QDomDocument::ParseResult *_ptr = reinterpret_cast<QDomDocument::ParseResult *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new ParseResult()
void __qt_construct_QDomDocument_ParseResult(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ParseResult()")
    Q_UNUSED(__java_arguments)
    QDomDocument::ParseResult *__qt_this = new(__qtjambi_ptr) QDomDocument::ParseResult();
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
}

// QDomDocument::ParseResult::ParseResult()
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_initialize_1native__Lio_qt_xml_QDomDocument_00024ParseResult_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomDocument::ParseResult::ParseResult()")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomDocument_ParseResult, sizeof(QDomDocument::ParseResult), typeid(QDomDocument::ParseResult), 0, false, &deleter_QDomDocument_ParseResult, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new ParseResult(QDomDocument::ParseResult)
void __qt_construct_QDomDocument_ParseResult_cref_QDomDocument_ParseResult(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ParseResult(QDomDocument::ParseResult)")
    jobject other0 = __java_arguments[0].l;
    const QDomDocument::ParseResult& __qt_other0 = qtjambi_cast<const QDomDocument::ParseResult&>(__jni_env, other0);
    QDomDocument::ParseResult *__qt_this = new(__qtjambi_ptr) QDomDocument::ParseResult(__qt_other0);
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDomDocument::ParseResult::ParseResult(QDomDocument::ParseResult)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_initialize_1native__Lio_qt_xml_QDomDocument_00024ParseResult_2Lio_qt_xml_QDomDocument_00024ParseResult_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject other0)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomDocument::ParseResult::ParseResult(QDomDocument::ParseResult)")
    QTJAMBI_TRY {
        jvalue arguments;
        arguments.l = other0;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomDocument_ParseResult_cref_QDomDocument_ParseResult, sizeof(QDomDocument::ParseResult), typeid(QDomDocument::ParseResult), 0, false, &deleter_QDomDocument_ParseResult, &arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new ParseResult{QString,qsizetype,qsizetype}
void __qt_construct_QDomDocument_ParseResult_QString_qsizetype_qsizetype(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool, bool, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ParseResult{QString,qsizetype,qsizetype}")
    jstring errorMessage0 = static_cast<jstring>(__java_arguments[0].l);
    QString __qt_errorMessage0 = qtjambi_cast<QString>(__jni_env, errorMessage0);
    jlong errorLine1 = __java_arguments[1].j;
    Q_UNUSED(errorLine1)
    jlong errorColumn2 = __java_arguments[2].j;
    Q_UNUSED(errorColumn2)
    QDomDocument::ParseResult *__qt_this = new(__qtjambi_ptr) QDomDocument::ParseResult{__qt_errorMessage0, static_cast<qsizetype>(errorLine1), static_cast<qsizetype>(errorColumn2)};
    Q_UNUSED(__qt_this)
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
}

// QDomDocument::ParseResult::ParseResult{QString,qsizetype,qsizetype}
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_initialize_1native__Lio_qt_xml_QDomDocument_00024ParseResult_2Ljava_lang_String_2JJ)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jstring errorMessage0,
 jlong errorLine1,
 jlong errorColumn2)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomDocument::ParseResult::ParseResult{QString,qsizetype,qsizetype}")
    QTJAMBI_TRY {
        jvalue arguments[3];
        arguments[0].l = errorMessage0;
        arguments[1].j = errorLine1;
        arguments[2].j = errorColumn2;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomDocument_ParseResult_QString_qsizetype_qsizetype, sizeof(QDomDocument::ParseResult), typeid(QDomDocument::ParseResult), 0, false, &deleter_QDomDocument_ParseResult, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QDomDocument::ParseResult
void __qt_destruct_QDomDocument_ParseResult(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomDocument::ParseResult")
    reinterpret_cast<QDomDocument::ParseResult*>(ptr)->~ParseResult();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomDocument::ParseResult::operator bool()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_success_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocument::ParseResult::operator bool()const", __this_nativeId)
        __java_return_value = __qt_this->operator bool();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomDocument::ParseResult::operator==(QDomDocument::ParseResult,QDomDocument::ParseResult)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_equals_1native_1cref_1QDomDocument_1ParseResult__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocument::ParseResult::operator==(QDomDocument::ParseResult,QDomDocument::ParseResult)", __this_nativeId)
        const QDomDocument::ParseResult& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QDomDocument::ParseResult>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_setErrorColumn_1native_1qsizetype__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jlong errorColumn0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->errorColumn = static_cast<qsizetype>(errorColumn0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_errorColumn_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qsizetype  __qt_value = __qt_this->errorColumn;
        __java_return_value = jlong(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_setErrorLine_1native_1qsizetype__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jlong errorLine0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->errorLine = static_cast<qsizetype>(errorLine0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_errorLine_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qsizetype  __qt_value = __qt_this->errorLine;
        __java_return_value = jlong(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_setErrorMessage_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring errorMessage0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString __qt_errorMessage0 = qtjambi_cast<QString>(__jni_env, errorMessage0);
        __qt_this->errorMessage = __qt_errorMessage0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_errorMessage_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QString&  __qt_value = __qt_this->errorMessage;
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomDocument_ParseResult(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomDocument::ParseResult>("QDomDocument::ParseResult", "io/qt/xml/QDomDocument$ParseResult");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, 0, &__qt_destruct_QDomDocument_ParseResult, {
        ConstructorInfo(&__qt_construct_QDomDocument_ParseResult, nullptr)
       ,ConstructorInfo(&__qt_construct_QDomDocument_ParseResult_cref_QDomDocument_ParseResult, "Lio/qt/xml/QDomDocument$ParseResult;")
       ,ConstructorInfo(&__qt_construct_QDomDocument_ParseResult_QString_qsizetype_qsizetype, "Ljava/lang/String;JJ")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomDocument_ParseResult);
    registerMetaType<QDomDocument::ParseResult>("QDomDocument::ParseResult");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-xml-debuginfo-windows-x64-6.6.0.jar: sources/QtJambiXml/QDomDocument_ParseResult_shell.cpp <==
#include <QtCore/QtGlobal>
#include <QtXml/qdom.h>
#include <QtCore/QVariant>

#include <QtJambi/QtJambiAPI>
#include <QtJambiXml/hashes.h>

#include <QtJambi/RegistryAPI>
#include <QtJambi/Cast>

void deleter_QDomDocument_ParseResult(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QDomDocument::ParseResult")
    QDomDocument::ParseResult *_ptr = reinterpret_cast<QDomDocument::ParseResult *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

// emitting (writeConstructors)
// new 
void __qt_construct_QDomDocument_ParseResult_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct ")
    Q_UNUSED(__java_arguments)
    QDomDocument::ParseResult *__qt_this = new(__qtjambi_ptr) QDomDocument::ParseResult();
    Q_UNUSED(__jni_object)
    Q_UNUSED(__jni_env)
    Q_UNUSED(__qt_this)
}

// destruct QDomDocument::ParseResult
void __qt_destruct_QDomDocument_ParseResult(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QDomDocument::ParseResult")
    reinterpret_cast<QDomDocument::ParseResult*>(ptr)->~ParseResult();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QDomDocument::ParseResult::
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_initialize_1native__Lio_qt_xml_QDomDocument_00024ParseResult_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object)
{
    QTJAMBI_NATIVE_METHOD_CALL("QDomDocument::ParseResult::")
    QTJAMBI_TRY {
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QDomDocument_ParseResult_0, sizeof(QDomDocument::ParseResult), typeid(QDomDocument::ParseResult), false, &deleter_QDomDocument_ParseResult, nullptr);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QDomDocument::ParseResult::operator bool()const
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_success_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        const QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocument::ParseResult::operator bool()const", __qt_this)
        __java_return_value = __qt_this->operator bool();
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// QDomDocument::ParseResult::operator==(QDomDocument::ParseResult,QDomDocument::ParseResult)
extern "C" Q_DECL_EXPORT jboolean JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_operator_1equal_1native_1cref_1QDomDocument_1ParseResult__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID value21)
{
    Q_UNUSED(__this)
    jboolean __java_return_value{0};
    QTJAMBI_TRY {
        QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QDomDocument::ParseResult::operator==(QDomDocument::ParseResult,QDomDocument::ParseResult)", __qt_this)
        const QDomDocument::ParseResult& __qt_value21 = QtJambiAPI::valueReferenceFromNativeId<QDomDocument::ParseResult>(value21);
        __java_return_value = (*__qt_this) == __qt_value21;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_setErrorColumn_1native_1qsizetype__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jlong errorColumn0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->errorColumn = static_cast<qsizetype>(errorColumn0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_errorColumn_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qsizetype  __qt_value = __qt_this->errorColumn;
        __java_return_value = jlong(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_setErrorLine_1native_1qsizetype__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jlong errorLine0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __qt_this->errorLine = static_cast<qsizetype>(errorLine0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jlong JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_errorLine_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jlong __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        qsizetype  __qt_value = __qt_this->errorLine;
        __java_return_value = jlong(__qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_setErrorMessage_1native_1cref_1QString__JLjava_lang_String_2)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 jstring errorMessage0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QString  __qt_errorMessage0 = qtjambi_cast<QString>(__jni_env, errorMessage0);
        __qt_this->errorMessage = __qt_errorMessage0;
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

extern "C" Q_DECL_EXPORT jstring JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_errorMessage_1native__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    jstring __java_return_value{0};
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        const QString&  __qt_value = __qt_this->errorMessage;
        __java_return_value = qtjambi_cast<jstring>(__jni_env, __qt_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;
}

// emitting (writeJavaLangObjectOverrideFunctions)

extern "C" Q_DECL_EXPORT jint JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_hashCode_1native)
(JNIEnv * __jni_env, jclass, QtJambiNativeID __this_nativeId)
{
    jint __java_return_value = 0;
    QTJAMBI_TRY {
        QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        hash_type hashValue = qHash(*__qt_this);
        __java_return_value = jint(quint64(hashValue) ^ quint64(hashValue) >> 32);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}
// emitting (writeCloneFunction)

extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_xml_QDomDocument_00024ParseResult_clone_1native)
(JNIEnv *__jni_env, jobject, QtJambiNativeID __this_nativeId)
{
    jobject __java_return_value = nullptr;
    QTJAMBI_TRY {
        const QDomDocument::ParseResult *__qt_this = QtJambiAPI::objectFromNativeId<QDomDocument::ParseResult>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        __java_return_value = qtjambi_cast<jobject>(__jni_env, *__qt_this);
    } QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    } QTJAMBI_TRY_END
    return __java_return_value;
}


void initialize_meta_info_QDomDocument_ParseResult(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerValueTypeInfo<QDomDocument::ParseResult>("QDomDocument::ParseResult", "io/qt/xml/QDomDocument$ParseResult");
    Q_UNUSED(typeId)
// BEGIN: function table
    registerConstructorInfos(typeId, &__qt_destruct_QDomDocument_ParseResult, {
        ConstructorInfo(&__qt_construct_QDomDocument_ParseResult_0, nullptr)
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QDomDocument_ParseResult);
    registerMetaType<QDomDocument::ParseResult>("QDomDocument::ParseResult");
// END: type registration

// BEGIN: polymorphic ids
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
